@@ -2,11 +2,12 @@
 Implementation of the asdf.info(...) function.  This is just a thin wrapper
 around _display module code.
 """
+
 import pathlib
 from contextlib import contextmanager
 
+from ._asdf import AsdfFile, open_asdf
 from ._display import DEFAULT_MAX_COLS, DEFAULT_MAX_ROWS, DEFAULT_SHOW_VALUES, render_tree
-from .asdf import AsdfFile, open_asdf
 
 __all__ = ["info"]
 
@@ -17,7 +18,7 @@ def info(node_or_path, max_rows=DEFAULT_MAX_ROWS, max_cols=DEFAULT_MAX_COLS, sho
 
     Parameters
     ----------
-    node_or_path : str, pathlib.Path, asdf.asdf.AsdfFile, or any ASDF tree node
+    node_or_path : str, pathlib.Path, asdf.AsdfFile, or any ASDF tree node
         The tree or sub-tree to render.  Strings and Path objects
         will first be passed to asdf.open(...).
 
