@@ -156,7 +156,7 @@ tags:
     foo_schema = """
 %YAML 1.1
 ---
-$schema: "asdf://stsci.edu/schemas/asdf/asdf-schema-1.0.0"
+$schema: "asdf://stsci.edu/schemas/asdf/asdf-schema-1.1.0"
 id: "asdf://somewhere.org/asdf/schemas/foo-1.0.0"
 
 type: object
@@ -221,7 +221,7 @@ properties:
     bar_schema = """
 %YAML 1.1
 ---
-$schema: "asdf://stsci.edu/schemas/asdf/asdf-schema-1.0.0"
+$schema: "asdf://stsci.edu/schemas/asdf/asdf-schema-1.1.0"
 id: "asdf://somewhere.org/asdf/schemas/bar-1.0.0"
 
 type: object
@@ -245,7 +245,7 @@ properties:
     drink_schema = """
 %YAML 1.1
 ---
-$schema: "asdf://stsci.edu/schemas/asdf/asdf-schema-1.0.0"
+$schema: "asdf://stsci.edu/schemas/asdf/asdf-schema-1.1.0"
 id: "asdf://somewhere.org/asdf/schemas/drink-1.0.0"
 
 type: object
@@ -633,6 +633,9 @@ class RecursiveObjectWithInfoSupport:
     def __asdf_traverse__(self):
         return {"the_meaning": self.the_meaning, "clown": self.clown, "recursive": self.recursive}
 
+    def __str__(self):
+        return "rec ref"
+
 
 def test_recursive_info_object_support(capsys, tmp_path):
     tempdir = pathlib.Path(tempfile.mkdtemp())
@@ -644,7 +647,14 @@ def test_recursive_info_object_support(capsys, tmp_path):
     recursive_obj = RecursiveObjectWithInfoSupport()
     recursive_obj.recursive = recursive_obj
     tree = {"random": 3.14159, "rtest": recursive_obj}
-    af = asdf.AsdfFile(tree)
+    af = asdf.AsdfFile()
+    # we need to do this to avoid validation against the
+    # manifest (generated in manifest_extension) which is
+    # now supported with the default asdf standard 1.6.0
+    # I'm not sure why the manifest has this restriction
+    # and prior to switching to the default 1.6.0 was ignored
+    # which allowed this test to pass.
+    af._tree = tree
     af.info(refresh_extension_manager=True)
     captured = capsys.readouterr()
     assert "recursive reference" in captured.out
@@ -662,3 +672,33 @@ def test_search():
 
     result = af.search(value="hello")
     assert result.node == "hello"
+
+
+def test_info_str(capsys):
+    class BadStr:
+        def __str__(self):
+            raise Exception()
+
+    class NewlineStr:
+        def __str__(self):
+            return "a\nb"
+
+    class CarriageReturnStr:
+        def __str__(self):
+            return "a\rb"
+
+    class NiceStr:
+        def __str__(self):
+            return "nice"
+
+    af = asdf.AsdfFile()
+    af["a"] = BadStr()
+    af["b"] = NewlineStr()
+    af["c"] = CarriageReturnStr()
+    af["d"] = NiceStr()
+    af.info()
+    captured = capsys.readouterr()
+    assert "(BadStr)\n" in captured.out
+    assert "(NewlineStr)\n" in captured.out
+    assert "(CarriageReturnStr)\n" in captured.out
+    assert "(NiceStr): nice\n" in captured.out
