@@ -2,10 +2,9 @@
 Support for Converter, the new API for serializing custom
 types.  Will eventually replace the `asdf.types` module.
 """
-import abc
-import warnings
 
-from asdf.exceptions import AsdfWarning
+import abc
+
 from asdf.util import get_class_name, uri_match
 
 
@@ -27,12 +26,17 @@ class Converter(abc.ABC):
         tags : list of str
             List of active tags to choose from.  Guaranteed to match
             one of the tag patterns listed in the 'tags' property.
-        ctx : asdf.asdf.SerializationContext
+        ctx : asdf.extension.SerializationContext
             Context of the current serialization request.
 
     and return a str, the selected tag (should be one of tags) or
     `None` which will trigger the result of ``to_yaml_tree`` to be
     used to look up the next converter for this object.
+
+    The ``lazy`` attribute is optional. If ``True`` asdf will
+    pass "lazy" objects to the converter. If ``False`` (or not
+    defined) asdf will convert all child objects before calling
+    `from_yaml_tree`.
     """
 
     @classmethod
@@ -116,7 +120,10 @@ class Converter(abc.ABC):
 
         For container types received by this method (dict or list),
         the children of the container will have already been converted
-        by prior calls to from_yaml_tree implementations.
+        by prior calls to from_yaml_tree implementations unless
+        ``lazy_tree`` was set to ``True`` for `asdf.open`. With a lazy
+        tree the container types will be `asdf.lazy_nodes` (which act
+        like dict or list but convert child objects when accessed).
 
         Note on circular references: trees that reference themselves
         among their descendants must be handled with care.  Most
@@ -170,23 +177,8 @@ class ConverterProxy(Converter):
                 raise TypeError(msg)
 
         if len(relevant_tags) > 1 and not hasattr(delegate, "select_tag"):
-            # we cannot use isinstance here because Converter supports
-            # virtual subclasses
-            if Converter in delegate.__class__.__mro__:
-                # prior to asdf 3.0 Converter provided a default select_tag
-                # to provide backwards compatibility allow Converter subclasses
-                # to be registered with >1 tag but produce a warning
-                msg = (
-                    "Converter handles multiple tags for this extension, "
-                    "but does not implement a select_tag method. "
-                    "This previously worked because Converter subclasses inherited "
-                    "the now removed select_tag. This will be an error in a future "
-                    "version of asdf"
-                )
-                warnings.warn(msg, AsdfWarning)
-            else:
-                msg = "Converter handles multiple tags for this extension, but does not implement a select_tag method."
-                raise RuntimeError(msg)
+            msg = "Converter handles multiple tags for this extension, but does not implement a select_tag method."
+            raise RuntimeError(msg)
 
         self._tags = sorted(relevant_tags)
 
@@ -203,6 +195,17 @@ class ConverterProxy(Converter):
                 msg = "Converter property 'types' must contain str or type values"
                 raise TypeError(msg)
 
+    @property
+    def lazy(self):
+        """
+        Boolean indicating if this Converter supports "lazy" node objects
+
+        Returns
+        -------
+        bool
+        """
+        return getattr(self._delegate, "lazy", False)
+
     @property
     def tags(self):
         """
